@@ -2,7 +2,7 @@ import argparse
 import os
 
 from tasq_cli import settings
-from tasq_cli.upload import do_upload
+from tasq_cli.upload import do_upload, create_csv_from_currently_uploaded_files
 
 from django.utils.text import slugify
 
@@ -19,11 +19,17 @@ def main():
     # in Python 3.8 you can pass an additional argument to add_subparsers
     # required=True
     subparsers = parser.add_subparsers(dest='action', metavar='action', help='action to run')
+
     images_parser = subparsers.add_parser('upload', help='upload files')
     images_parser.add_argument('-p', '--path', default=False, help='path to directory with images')
     images_parser.add_argument('-e', '--exclude', help='File extensions to exclude.', action='append', nargs='*')
     images_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
 
+    csv_parser = subparsers.add_parser('create_csv', help='upload files')
+    csv_parser.add_argument('-d', '--csv-dataset-name', action='store', help='dataset name of csv to create')
+    csv_parser.add_argument('-f', '--file-name', action='store', help='one file from dataset of csv to create')
+    csv_parser.add_argument('--dry', help='create upload file but dont actually upload anything', action='store_true')
+
     args = parser.parse_args()
     logger = settings.get_logger()
 
@@ -60,3 +66,6 @@ def main():
     if args.action == 'upload':
         settings.dry = args.dry
         do_upload(DATASET_NAME, args.path, args.exclude, settings)
+
+    if args.action == 'create_csv':
+        create_csv_from_currently_uploaded_files(args.csv_dataset_name, args.file_name, settings) 
