@@ -7,6 +7,7 @@ import uuid
 import json
 import boto3
 from botocore.exceptions import ClientError
+from django.utils.text import slugify
 
 # import settings
 from tasq_cli.db import UploadsDatabase
@@ -71,7 +72,7 @@ def upload_file(dataset_name, db, settings, client, file_name_with_path, leaf_pa
                         'TagSet': [
                             {
                                 'Key': 'original_name',
-                                'Value': file_name.replace(',', '_') # TODO make this hotfix more robust
+                                'Value': slugify(file_name)
                             },
                         ]
                     }
@@ -165,3 +166,37 @@ def do_upload(dataset_name, search_path, exclude, settings):
     with open(f'./out/{dataset_name}.csv', 'w') as csvfile:
         csvwriter = csv.writer(csvfile, dialect='unix')
         csvwriter.writerows(csv_rows)
+
+def create_csv_from_currently_uploaded_files(dataset_name, file_name, settings):
+    db = UploadsDatabase()
+    global logger
+    logger = settings.get_logger()
+
+    if not dataset_name:
+        if not file_name:
+            logger.error('No dataset_name or example file_name was provided.')
+            return
+        res = get_dataset_name(db, file_name)
+        if not res:
+            logger.error('No such file was uploaded.')
+            return
+        dataset_name = res[0]
+
+    entries = db.get_uploaded_files_by_dataset_name(dataset_name)
+    row_values = {'file_name': 0, 'cdn_url': 1}
+    csv_rows = [
+        [
+            entry[row_values['cdn_url']],
+            json.dumps({'file_name': entry[row_values['file_name']]}),  # object
+        ] for entry in entries]
+    with open(f'./out/{dataset_name}.csv', 'w') as csvfile:
+        csvwriter = csv.writer(csvfile, dialect='unix')
+        csvwriter.writerows(csv_rows)
+
+
+def get_dataset_name(db, file_name):
+    file_path, file_name = os.path.split(file_name)
+    leaf_path = os.path.basename(os.path.normpath(file_path))
+    relative_file_path = f'{leaf_path}{file_path.split(leaf_path)[-1]}'.replace('-', '_')
+    res = db.get_dataset_name_by_filename(f'{relative_file_path}/{file_name}')
+    return res
